==> nui_form-0.0.52.tar.gz: lib/component/nuif_button.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';

enum NUIFTButtonDesign{
  FILL,
  OUTLINE
}

class NUIFButtonStyle{
  static const Color DEFAULT_RIPPLE_COLOR = Color(0x30000000);

  NUIFButtonStyle({
    this.rippleColor: DEFAULT_RIPPLE_COLOR,
    @required this.normalColor,
    this.design: NUIFTButtonDesign.FILL,
    this.outlineColor:NUIColors.NUIBlack,
    this.outlineThickness:2,
    this.radius:10,
    this.borderRadius,
    this.textStyle,
    this.textAlign,
    this.elevation,
    this.gradients,
    this.orientation,
    this.padding: const EdgeInsets.only(left: 20, right: 20, top: 10, bottom: 10),
  });

  TextStyle textStyle;
  EdgeInsets padding;
  TextAlign textAlign;
  Color rippleColor;
  Color normalColor;
  Color outlineColor;
  double outlineThickness;
  NUIFTButtonDesign design;
  double radius;
  double elevation;
  BorderRadius borderRadius;
  List<Color> gradients;
  GradientOrientation orientation;
}

class NUIFButtonItem extends NUIFormComponent{
  NUIFButtonItem({
    @required String inpId,
    double width,
    double height,
    double weight,
    bool enabled: true,
    @required this.text,
    @required this.onTap,
    this.onDoubleTap,
    this.onLongPress,
    this.enabledStyle,
    this.disabledStyle,
    Alignment align,
    EdgeInsets margin,
  }) : super(inpId: inpId, inpType:ComponentType.TEXT, width: width, height : height, weight: weight, enabled: enabled, margin: margin, align: align);

  String text;
  GestureTapCallback onTap;
  GestureTapCallback onDoubleTap;
  GestureLongPressCallback onLongPress;
  NUIFButtonStyle enabledStyle;
  NUIFButtonStyle disabledStyle;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFButton(item: this, allButtonClickListener: allButtonClickListener, key: key);
  }

  @override
  bool validate(bool quiet){
    return true;
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
    map[inpId] = NUIFormValue(inpId: inpId, value: NUIFormSelection(code: inpId, value: text));
  }
}

class NUIFButton extends StatefulWidget {
  NUIFButton({@required this.item, this.allButtonClickListener, Key key}): super(key: key);
  final NUIFButtonItem item;
  final AllButtonClickListener allButtonClickListener;
  @override
  _NUIFButtonState createState() => _NUIFButtonState();
}

class _NUIFButtonState extends NUIFState<NUIFButton, NUIFButtonItem> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _bindWithItem(NUIFButtonItem item){

    bool isEnabled = item.enabled;
    NUIFButtonStyle style = isEnabled ? item.enabledStyle : item.disabledStyle ?? item.enabledStyle;

    final text = Text(
      item.text,
      style: style?.textStyle,
      textAlign: style?.textAlign
    );

    BoxDecoration outlineBorder;
    if(style?.design == NUIFTButtonDesign.OUTLINE) {
      outlineBorder = NUIOutlineDecoration(
          outlineColor: style?.outlineColor,
          innerColor: style?.normalColor,
          radius: style?.borderRadius,
          thickness: style?.outlineThickness
      );
    }
    else if(!NUIDataUtil.isNullOrEmpty(style.gradients)){
      outlineBorder = BoxDecoration(
        gradient: NUILinearGradient(
          colors: style.gradients,
          orientation: style.orientation
        ),
        borderRadius: style?.borderRadius
      );
    }

    final child = Container(
        alignment: Alignment.center,
        child: text,
        width: item.width,
        height: item.height,
        padding: style?.padding,
        decoration: outlineBorder,
    );

    Widget button;
    if(style?.design != NUIFTButtonDesign.OUTLINE) {
      button = RaisedButton(
        shape: RoundedRectangleBorder(
          borderRadius: style.borderRadius,
        ),
        onPressed: () {
          if (item.onTap != null) {
            item.onTap();
          }
          widget.allButtonClickListener(item.inpId, ClickType.TAP);
        },
        onLongPress: item.onLongPress != null ? () {
          if (item.onLongPress != null) {
            item.onLongPress();
          }
          widget.allButtonClickListener(item.inpId, ClickType.LONG_TAP);
        } : null,
        child: child,
        padding: EdgeInsets.all(0),
        elevation: style.elevation ?? 3,
        color: outlineBorder == null ? style?.normalColor : NUIColors.NUITransparent,
      );
    }
    else{
      button = FlatButton(
        shape: RoundedRectangleBorder(
          borderRadius: style.borderRadius,
        ),
        onPressed: () {
          if (item.onTap != null) {
            item.onTap();
          }
          widget.allButtonClickListener(item.inpId, ClickType.TAP);
        },
        onLongPress: item.onLongPress != null ? () {
          if (item.onLongPress != null) {
            item.onLongPress();
          }
          widget.allButtonClickListener(item.inpId, ClickType.LONG_TAP);
        } : null,
        padding: EdgeInsets.all(0),
        child: child,
        color: style?.normalColor,
      );
    }

    return button;
  }

  @override
  Widget build(BuildContext context) {
    return item.wrapWidget(_bindWithItem(item));
  }
}

==> nui_form-0.0.56.tar.gz: lib/component/nuif_button.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';

enum NUIFTButtonDesign{
  FILL,
  OUTLINE
}

class NUIFButtonStyle{
  static const Color DEFAULT_RIPPLE_COLOR = Color(0x30000000);

  NUIFButtonStyle({
    this.rippleColor: DEFAULT_RIPPLE_COLOR,
    @required this.normalColor,
    this.design: NUIFTButtonDesign.FILL,
    this.outlineColor:NUIColors.NUIBlack,
    this.outlineThickness:2,
    this.radius:10,
    this.borderRadius,
    this.textStyle,
    this.textAlign,
    this.elevation,
    this.gradients,
    this.orientation,
    this.padding: const EdgeInsets.only(left: 20, right: 20, top: 10, bottom: 10),
  });

  TextStyle textStyle;
  EdgeInsets padding;
  TextAlign textAlign;
  Color rippleColor;
  Color normalColor;
  Color outlineColor;
  double outlineThickness;
  NUIFTButtonDesign design;
  double radius;
  double elevation;
  BorderRadius borderRadius;
  List<Color> gradients;
  GradientOrientation orientation;
}

class NUIFButtonItem extends NUIFormComponent{
  NUIFButtonItem({
    @required String inpId,
    double width,
    double height,
    double weight,
    bool enabled: true,
    @required this.text,
    @required this.onTap,
    this.onDoubleTap,
    this.onLongPress,
    this.enabledStyle,
    this.disabledStyle,
    Alignment align,
    EdgeInsets margin,
  }) : super(inpId: inpId, inpType:ComponentType.TEXT, width: width, height : height, weight: weight, enabled: enabled, margin: margin, align: align);

  String text;
  GestureTapCallback onTap;
  GestureTapCallback onDoubleTap;
  GestureLongPressCallback onLongPress;
  NUIFButtonStyle enabledStyle;
  NUIFButtonStyle disabledStyle;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFButton(item: this, allButtonClickListener: allButtonClickListener, key: key);
  }

  @override
  bool validate(bool quiet){
    return true;
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
    map[inpId] = NUIFormValue(inpId: inpId, value: NUIFormSelection(code: inpId, value: text));
  }

  @override
  void fillInValue(Map<String, NUIFormValue> values) {
    //Do nothing for buttons
  }
}

class NUIFButton extends StatefulWidget {
  NUIFButton({@required this.item, this.allButtonClickListener, Key key}): super(key: key);
  final NUIFButtonItem item;
  final AllButtonClickListener allButtonClickListener;
  @override
  _NUIFButtonState createState() => _NUIFButtonState();
}

class _NUIFButtonState extends NUIFState<NUIFButton, NUIFButtonItem> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _bindWithItem(NUIFButtonItem item){

    bool isEnabled = item.enabled;
    NUIFButtonStyle style = isEnabled ? item.enabledStyle : item.disabledStyle ?? item.enabledStyle;

    final text = Text(
      item.text,
      style: style?.textStyle,
      textAlign: style?.textAlign
    );

    BoxDecoration outlineBorder;
    if(style?.design == NUIFTButtonDesign.OUTLINE) {
      outlineBorder = NUIOutlineDecoration(
          outlineColor: style?.outlineColor,
          innerColor: style?.normalColor,
          borderRadius: style?.borderRadius,
          thickness: style?.outlineThickness
      );
    }
    else if(!NUIDataUtil.isNullOrEmpty(style.gradients)){
      outlineBorder = BoxDecoration(
        gradient: NUILinearGradient(
          colors: style.gradients,
          orientation: style.orientation
        ),
        borderRadius: style?.borderRadius
      );
    }

    final child = Container(
        alignment: Alignment.center,
        child: text,
        width: item.width,
        height: item.height,
        padding: style?.padding,
        decoration: outlineBorder,
    );

    Widget button;
    if(style?.design != NUIFTButtonDesign.OUTLINE) {
      button = RaisedButton(
        shape: RoundedRectangleBorder(
          borderRadius: style.borderRadius,
        ),
        onPressed: () {
          if (item.onTap != null) {
            item.onTap();
          }
          widget.allButtonClickListener(item.inpId, ClickType.TAP);
        },
        onLongPress: item.onLongPress != null ? () {
          if (item.onLongPress != null) {
            item.onLongPress();
          }
          widget.allButtonClickListener(item.inpId, ClickType.LONG_TAP);
        } : null,
        child: child,
        padding: EdgeInsets.all(0),
        elevation: style.elevation ?? 3,
        color: outlineBorder == null ? style?.normalColor : NUIColors.NUITransparent,
      );
    }
    else{
      button = FlatButton(
        shape: RoundedRectangleBorder(
          borderRadius: style.borderRadius,
        ),
        onPressed: () {
          if (item.onTap != null) {
            item.onTap();
          }
          widget.allButtonClickListener(item.inpId, ClickType.TAP);
        },
        onLongPress: item.onLongPress != null ? () {
          if (item.onLongPress != null) {
            item.onLongPress();
          }
          widget.allButtonClickListener(item.inpId, ClickType.LONG_TAP);
        } : null,
        padding: EdgeInsets.all(0),
        child: child,
        color: style?.normalColor,
      );
    }

    return button;
  }

  @override
  Widget build(BuildContext context) {
    return item.wrapWidget(_bindWithItem(item));
  }
}
